#import "SearchController.h"
#import "MyDocument.h"

@implementation SearchController

- (id)init
{
	_query = [[NSMetadataQuery alloc] init];
	
	// Restrict the search to our working directory
	NSString *path = [@"~/Library/QNotes" stringByExpandingTildeInPath];
	[_query setSearchScopes:[NSArray arrayWithObjects:path,nil]];

	return self;
}


- (void)dealloc {
    [_query release];
    [_searchKey release];
    [super dealloc];
}

- (IBAction)orderOutSearchPanel:(id)sender
{
	if (searchPanel == nil) {
		if (![NSBundle loadNibNamed:@"SearchPanel" owner:self])  {
            NSLog(@"Failed to load SearchPanel.nib");
            NSBeep();
            return;
        }
	}
	[searchPanel makeKeyAndOrderFront:sender];
}


// In the nib file, we will bind to "query.results" in the ArrayControler
- (NSMetadataQuery *)query {
printf("In query, %d results \n", [_query resultCount]);
    return _query;
}

// In the nib file, the NSSearchField's value is bound to "searchKey"
- (NSString *)searchKey {
    return [[_searchKey copy] autorelease];
}

// The search key gets set from the search box through bindings
- (void)setSearchKey:(NSString *) value {
    if (_searchKey != value) {
        [_searchKey release];
        if (value == nil) value = @"";
        _searchKey = [value copy];
        [self runTheQuery];
    }
}

- (void) runTheQuery
{
	// set predicate
	// in future this will depend on the search menu selection
	NSString *predicateFormat = @"kMDItemTextContent like[cd] %@";	

	NSPredicate *p = [NSPredicate predicateWithFormat:predicateFormat,_searchKey];
	[_query setPredicate:p];

	
	// Tell the query to sort according to relevancy and age
	[_query setSortDescriptors:[NSArray arrayWithObjects:
		[[[NSSortDescriptor alloc] initWithKey:NSMetadataQueryResultContentRelevanceAttribute ascending:NO] autorelease],
		[[[NSSortDescriptor alloc] initWithKey:(id)kMDItemContentModificationDate ascending:NO] autorelease],
			nil]];
	
	// and go ..
	
	[_query startQuery];
	
}

- (void) killQuery:(id)sender
{
	[_query stopQuery];
	
}


- (void)openFile:(NSString *)path
{
	[_query stopQuery];
	[[NSWorkspace sharedWorkspace] openFile:path withApplication:@"QNote.app"];
	[searchPanel close];
}
@end
